==> mkm-0.10.10.tar.gz: mkm-0.10.10/mkm/__init__.py <==
# -*- coding: utf-8 -*-
#
#   Ming-Ke-Ming : Decentralized User Identity Authentication
#
#                                Written in 2019 by Moky <albert.moky@gmail.com>
#
# ==============================================================================
# MIT License
#
# Copyright (c) 2019 Albert Moky
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# ==============================================================================

from .crypto import *

from .types import NetworkType, MetaType
from .address import Address, AddressFactory, ANYWHERE, EVERYWHERE
from .identifier import ID, ANYONE, EVERYONE
from .meta import Meta, BaseMeta
from .tai import Document
from .profile import Visa, Bulletin, BaseDocument, BaseVisa, BaseBulletin

name = "MingKeMing"

__author__ = 'Albert Moky'

__all__ = [

    'NetworkType', 'MetaType',
    'Address', 'AddressFactory',
    'ID', 'ANYONE', 'EVERYONE', 'ANYWHERE', 'EVERYWHERE',
    'Meta', 'BaseMeta',
    'Document', 'BaseDocument',
    'Visa', 'BaseVisa', 'Bulletin', 'BaseBulletin',
]

==> mkm-2.3.4.tar.gz: mkm-2.3.4/mkm/__init__.py <==
# -*- coding: utf-8 -*-
#
#   Ming-Ke-Ming : Decentralized User Identity Authentication
#
#                                Written in 2019 by Moky <albert.moky@gmail.com>
#
# ==============================================================================
# MIT License
#
# Copyright (c) 2019 Albert Moky
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# ==============================================================================

from .protocol import *

from .protocol.address import AddressFactory
from .protocol.identifier import IDFactory
from .protocol.meta import MetaFactory
from .protocol.tai_doc import DocumentFactory

from .identifier import Identifier
from .identifier import ANYONE, EVERYONE, FOUNDER
from .address import ANYWHERE, EVERYWHERE
# from .address import BroadcastAddress


name = "MingKeMing"

__author__ = 'Albert Moky'

__all__ = [

    #
    #   Protocol
    #

    'EntityType',
    'Address',
    'ID',
    'Meta',
    # 'TAI',
    'Document',

    #
    #   Factories
    #

    'AddressFactory',
    'IDFactory',
    'MetaFactory',
    'DocumentFactory',

    #
    #   Core
    #

    'Identifier',

    'ANYONE', 'EVERYONE', 'FOUNDER',
    'ANYWHERE', 'EVERYWHERE',

    # 'BroadcastAddress',

]
